# valve.py
VALVE in Python

* [Command Line Usage](#command-line-usage)
	* [Configuration Files](#configuration-files)
	* [Functions](#functions)
	* [Other Options](#other-options)
* [API](#api)

## Setup

The latest release of VALVE can be downloaded from PyPI using `pip install`:
```
python3 -m pip install ontodev-valve
```

Alternatively, for the developer version, you may clone this repository, navigate to it, and install locally:
```
python3 -m pip install .
```

To confirm installation, run `valve -h`

## Command Line Usage

For details on command line usage, please [see here](https://github.com/ontodev/valve/blob/main/README.md#command-line-usage).

## API

For details on the VALVE API, please [see here](https://github.com/ontodev/valve/blob/main/README.md#api).
